@@ -1,5 +1,6 @@
+import os
+
 from .routes.collector import Collector
-from .session.interfaces import ISessionProvider
 from .util.logger import Logger
 
 
@@ -9,9 +10,7 @@ class AppContext:
     def __init__(self, app_id: str,
                  app_root: str,
                  debug_mode: bool,
-                 url_endswith_slash: bool,
-                 session_provider: ISessionProvider,
-                 sessionid_name: str):
+                 append_slash: bool):
         """
 
         """
@@ -22,7 +21,7 @@ class AppContext:
         self.DEBUG = debug_mode
         # 工作目录
         self.ROOT = app_root
-        self.url_endswith_slash = url_endswith_slash
+        self.append_slash = append_slash
         # 注册的中间件实例集合
         self.middlewares = []
         """
@@ -36,14 +35,14 @@ class AppContext:
         # 路由映射表，其键为请求的路径，其值为映射的目录
         self.routes_map = {}
 
-        self.session_provider = session_provider
-        """
-        :type: ISessionProvider
-        """
+        self.static_map = {}
 
-        self.sessionid_name = sessionid_name
+        self.dev_options = {}
 
-        self.collector = Collector(app_root, url_endswith_slash)
+        if debug_mode:
+            self.static_map['/restfx_assets_for_dev'] = os.path.join(os.path.dirname(__file__), 'assets_for_dev')
+
+        self.collector = Collector(app_root, append_slash)
         self.logger = Logger(debug_mode)
         # debug 状态变化时的处理函数
         self.debug_changed_handlers = [self.logger.on_debug_mode_changed]
